@@ -5,7 +5,8 @@
 #' Likely to be removed/replaced in later releases by functionality drawing on
 #' the `stan` implementation.
 #'
-#' @param case_estimates A data.table of case estimates with the following variables: date, sample, cases
+#' @param case_estimates A data.table of case estimates with the following
+#' variables: date, sample, cases
 #'
 #' @param case_forecast A data.table of case forecasts with the following
 #' variables: date, sample, cases. If not supplied the default is not to
@@ -32,9 +33,13 @@
 #' cases <- example_confirmed[1:40]
 #'
 #' # set up example delays
-#' generation_time <- get_generation_time(disease = "SARS-CoV-2", source = "ganyani")
-#' incubation_period <- get_incubation_period(disease = "SARS-CoV-2", source = "lauer")
-#' reporting_delay <- list(
+#' generation_time <- get_generation_time(
+#'  disease = "SARS-CoV-2", source = "ganyani"
+#' )
+#' incubation_period <- get_incubation_period(
+#'  disease = "SARS-CoV-2", source = "lauer"
+#' )
+#' reporting_delay <- dist_spec(
 #'   mean = convert_to_logmean(2, 1), mean_sd = 0.1,
 #'   sd = convert_to_logsd(2, 1), sd_sd = 0.1, max = 10
 #' )
@@ -46,7 +51,7 @@
 #'
 #' reported_cases <- report_cases(
 #'   case_estimates = cases,
-#'   delays = delay_opts(incubation_period, reporting_delay),
+#'   delays = delay_opts(incubation_period + reporting_delay),
 #'   type = "sample"
 #' )
 #' print(reported_cases)
@@ -61,13 +66,13 @@ report_cases <- function(case_estimates,
 
   # define delay distributions
   delay_defs <- purrr::map(
-    seq_along(delays$delay_mean_mean),
+    seq_along(delays$mean_mean),
     ~ EpiNow2::lognorm_dist_def(
-      mean = delays$delay_mean_mean[.],
-      mean_sd = delays$delay_mean_sd[.],
-      sd = delays$delay_sd_mean[.],
-      sd_sd = delays$delay_sd_sd[.],
-      max_value = delays$delay_max[.],
+      mean = delays$mean_mean[.],
+      mean_sd = delays$mean_sd[.],
+      sd = delays$mean_mean[.],
+      sd_sd = delays$mean_sd[.],
+      max_value = delays$max[.],
       samples = samples
     )
   )
@@ -78,7 +83,9 @@ report_cases <- function(case_estimates,
       effect = rep(1, 7),
       day = 1:7
     )
-    reporting_effect <- reporting_effect[, .(sample = unlist(sample)), by = .(effect, day)]
+    reporting_effect <- reporting_effect[,
+      .(sample = unlist(sample)), by = .(effect, day)
+    ]
   }
   # filter and sum nowcast to use only upscaled cases by date of infection
   infections <- data.table::copy(case_estimates)
@@ -109,25 +116,31 @@ report_cases <- function(case_estimates,
   # bind all samples together
   out$samples <- report
   # summarise samples
-  out$summarised <- calc_summary_measures(report[, value := cases][, cases := NULL],
-    summarise_by = c("date"),
-    order_by = c("date"),
+  out$summarised <- calc_summary_measures(
+    report[, value := cases][, cases := NULL],
+    summarise_by = "date",
+    order_by = "date",
     CrIs = CrIs
   )
   return(out)
 }
 
-
 #' Provide Summary Statistics for Estimated Infections and Rt
 #' @description `r lifecycle::badge("questioning")`
-#' Creates a snapshot summary of estimates. May be removed in later releases as S3 methods are
-#' enhanced.
-#' @param summarised_estimates A data.table of summarised estimates containing the following variables:
-#'  variable, median, bottom, and top. It should contain the following estimates: R, infections, and r
-#'  (rate of growth).
-#' @param rt_samples A data.table containing Rt samples with the following variables: sample and value.
+#' Creates a snapshot summary of estimates. May be removed in later releases as
+#' S3 methods are enhanced.
+#'
+#' @param summarised_estimates A data.table of summarised estimates containing
+#' the following variables: variable, median, bottom, and top. It should
+#' contain the following estimates: R, infections, and r (rate of growth).
+#'
+#' @param rt_samples A data.table containing Rt samples with the following
+#' variables: sample and value.
+#'
 #' @param return_numeric Should numeric summary information be returned.
+#'
 #' @inheritParams setup_target_folder
+#'
 #' @return A data.table containing formatted and numeric summary measures
 #' @export
 #' @importFrom data.table data.table setDT
@@ -151,25 +164,24 @@ report_summary <- function(summarised_estimates,
   ]
 
   # extract latest R estimate
-  R_latest <- summarised_estimates[variable == "R"][, variable := NULL][
-    ,
-    purrr::map(.SD, ~ signif(., 2))
-  ]
+  R_latest <- summarised_estimates[variable == "R"][,
+    variable := NULL][, purrr::map(.SD, signif, digits = 2)]
 
   # estimate probability of control
-  prob_control <- rt_samples[, .(prob_control = sum(value <= 1) / .N)]$prob_control
+  prob_control <- rt_samples[,
+   .(prob_control = sum(value <= 1) / .N)
+  ]$prob_control
   prob_control <- signif(prob_control, 2)
 
   # extract current cases
-  current_cases <- summarised_estimates[variable == "infections"][, variable := NULL][
-    ,
+  current_cases <- summarised_estimates[variable == "infections"][,
+    variable := NULL][,
     purrr::map(.SD, ~ signif(as.integer(.)), 2)
   ]
 
   # get individual estimates
-  r_latest <- summarised_estimates[variable == "growth_rate"][, variable := NULL][
-    ,
-    purrr::map(.SD, ~ signif(., 2))
+  r_latest <- summarised_estimates[variable == "growth_rate"][,
+    variable := NULL][, purrr::map(.SD, signif, digits = 2)
   ]
 
   doubling_time <- function(r) {
@@ -190,7 +202,7 @@ report_summary <- function(summarised_estimates,
       "Expected change in daily cases",
       "Effective reproduction no.",
       "Rate of growth",
-      "Doubling/halving time (days)"
+      "Doubling/halving time (days)" # nolint
     ),
     estimate = c(
       make_conf(current_cases, max_CrI),
@@ -222,25 +234,32 @@ report_summary <- function(summarised_estimates,
 #' Report plots
 #'
 #' @description `r lifecycle::badge("questioning")`
-#' Returns key summary plots for estimates. May be depreciated in later releases as current S3 methods
-#' are enhanced.
+#' Returns key summary plots for estimates. May be depreciated in later
+#' releases as current S3 methods are enhanced.
+#'
 #' @param summarised_estimates A data.table of summarised estimates containing
 #' the following variables: variable, median, bottom, and top.
 #'
 #'  It should also contain the following estimates: R, infections,
 #'  reported_cases_rt, and r (rate of growth).
+#'
 #' @param ... Additional arguments passed to `plot_estimates()`.
+#'
 #' @importFrom ggplot2 ggsave theme labs scale_x_date theme_bw
 #' @importFrom patchwork plot_layout
 #' @importFrom data.table setDT
 #' @inheritParams setup_target_folder
 #' @inheritParams epinow
 #' @inheritParams plot_estimates
-#' @return A named list of `ggplot2` objects, `list(infections, reports, R, growth_rate, summary)`,
-#'   which correspond to a summary combination (last item) and for the leading items
-#'   @seealso [plot_estimates()] of `summarised_estimates[variable == "infections"]`,
-#'   `summarised_estimates[variable == "reported_cases"]`, `summarised_estimates[variable == "R"]`,
-#'   and `summarised_estimates[variable == "growth_rate"]`, respectively.
+#' @return A named list of `ggplot2` objects, `list(infections, reports, R,
+#' growth_rate, summary)`, which correspond to a summary combination (last
+#' item) and for the leading items.
+#'
+#' @seealso [plot_estimates()] of
+#' `summarised_estimates[variable == "infections"]`,
+#' `summarised_estimates[variable == "reported_cases"]`,
+#' `summarised_estimates[variable == "R"]`, and
+#' `summarised_estimates[variable == "growth_rate"]`, respectively.
 #' @export
 #' @examples
 #' \donttest{
@@ -248,15 +267,21 @@ report_summary <- function(summarised_estimates,
 #' cases <- example_confirmed[1:40]
 #'
 #' # set up example delays
-#' generation_time <- get_generation_time(disease = "SARS-CoV-2", source = "ganyani")
-#' incubation_period <- get_incubation_period(disease = "SARS-CoV-2", source = "lauer")
-#' reporting_delay <- bootstrapped_dist_fit(rlnorm(100, log(6), 1), max_value = 30)
+#' generation_time <- get_generation_time(
+#'  disease = "SARS-CoV-2", source = "ganyani"
+#' )
+#' incubation_period <- get_incubation_period(
+#'  disease = "SARS-CoV-2", source = "lauer"
+#' )
+#' reporting_delay <- bootstrapped_dist_fit(
+#'  rlnorm(100, log(6), 1), max_value = 30
+#' )
 #'
 #' # run model
 #' out <- estimate_infections(cases,
 #'   stan = stan_opts(samples = 500),
-#'   generation_time = generation_time,
-#'   delays = delay_opts(incubation_period, reporting_delay),
+#'   generation_time = generation_time_opts(generation_time),
+#'   delays = delay_opts(incubation_period + reporting_delay),
 #'   rt = NULL
 #' )
 #'
@@ -334,7 +359,7 @@ report_plots <- function(summarised_estimates, reported,
     )
   )
 
-  # organise output
+  # Organise output
   plots <- list(
     infections = infections,
     reports = reports,
@@ -355,7 +380,10 @@ report_plots <- function(summarised_estimates, reported,
         R = "reff_plot.png", growth_rate = "growth_rate_plot.png",
         summary = "summary_plot.png"
       ))
-      mapply(ggplot2::ggsave, filename = pths, plot = plots, width = wd, height = ht, dpi = dpi)
+      mapply(
+        ggplot2::ggsave, filename = pths, plot = plots,
+        width = wd, height = ht, dpi = dpi
+      )
     }))
   }
   return(plots)
