@@ -1,5 +1,5 @@
 generation_time <- get_generation_time(disease = "SARS-CoV-2", source = "ganyani", max_value = 5)
-reporting_delay <- list(
+reporting_delay <- dist_spec(
   mean = log(3), mean_sd = 0.1,
   sd = log(2), sd_sd = 0.1, max = 5
 )
@@ -18,7 +18,7 @@ df_non_zero <- function(df) {
 
 out <- suppressWarnings(regional_epinow(
   reported_cases = cases,
-  generation_time = generation_time,
+  generation_time = generation_time_opts(generation_time),
   delays = delay_opts(reporting_delay),
   stan = stan_opts(
     samples = 25, warmup = 25,
