@@ -3,9 +3,13 @@ test_that("report_cases can simulate infections forward", {
   cases <- example_confirmed[1:10]
 
   # set up example delays
-  generation_time <- get_generation_time(disease = "SARS-CoV-2", source = "ganyani")
-  incubation_period <- get_incubation_period(disease = "SARS-CoV-2", source = "lauer")
-  reporting_delay <- list(
+  generation_time <- get_generation_time(
+    disease = "SARS-CoV-2", source = "ganyani"
+  )
+  incubation_period <- get_incubation_period(
+    disease = "SARS-CoV-2", source = "lauer"
+  )
+  reporting_delay <- dist_spec(
     mean = convert_to_logmean(2, 1), mean_sd = 0.1,
     sd = convert_to_logsd(2, 1), sd_sd = 0.1, max = 5
   )
@@ -17,7 +21,7 @@ test_that("report_cases can simulate infections forward", {
   set.seed(123)
   reported_cases <- report_cases(
     case_estimates = cases,
-    delays = delay_opts(incubation_period, reporting_delay),
+    delays = delay_opts(incubation_period + reporting_delay),
     type = "sample"
   )
   expect_equal(class(reported_cases), "list")
